# Sharepoint Online Connector

Sharepoint Online has a complicated set up and we do not recommend this for the regular user. Sharepoint Online should only be implemented if you are familiar with administering Sharepoint Sites and currently have Sharepoint administration permissions.

## Prerequisites
- Existing Sharepoint Online Site
   - Instructions to create one can be followed with [Microsoft's tutorial here](https://support.microsoft.com/en-gb/office/create-a-site-in-sharepoint-4d1e11bf-8ddc-499d-b889-2b48d10b1ce8).
- Administrator access to a Sharepoint Online site.
- [Installation of Postman](https://www.postman.com/downloads/) or use of a free Postman account for their [web version](https://identity.getpostman.com/login).

## Create Client ID and Client Secret in your Sharepoint site

1) Retrieve your Sharepoint site's URL. Adjust this URL with your site:
```
https://<sitename.com>/<subsitedomain>/_layouts/15/appregnew.aspx
```
For example, our site is https://uwprod.sharepoint.com/sites/IICSRepo so our url will be: 
```
https://uwprod.sharepoint.com/sites/IICSRepo/_layouts/15/appregnew.aspx
```
2) Browse to the appregnew.aspx URL you've edited. This will load the registration form (pictured below). Generate a Client ID and Client Secret.
   - copy these onto a text document, you will not be able to retrieve the Secret once you close this browser window.
3) Create a title that fits this need, for example "IICS integrations".
4) App Domain can be anything, we suggest keeping it simple like www.informatica.com.
5) Redirect URI should be simple as well and will be used in a later step for token verification, so save what you've entered here.  We will use https://localhost/.
6) Click Create.

![NewApp](images/ClientIDandSecret.png)

## Find your Bearer Realm
[Informatica Reference](https://docs.informatica.com/integration-cloud/data-integration-connectors/current-version/microsoft-sharepoint-online-connector/introduction-to-microsoft-sharepoint-online-connector/administration-of-microsoft-sharepoint-online-connector/generate-the-bearer-realm.html)

1) Open Postman.
2) Click the "New" button for your scratch pad.
3) Enter the appregnew.aspx url we created in the previous section.
4) Make sure "GET" is selected in the drop menu left of the URL.
5) Make sure you select the "Headers" tab directly below the URL.
6) Add the Authorization Key and Bearer as it's Value.
7) Press the blue "Send" button.
8) The resulting Body below will give a 401 Unauthorized return, however when you select the Headers tab in the response pane we can retrieve the Bearer Realm from the WWW-Authenticate Key.
   - Save this value in your text document with the values from the previous section.
9) You will also want to copy the Client ID that follows the Bearer Realm value within the same field.

![BearerReam](images/BearerRealmPM.png)

## Get the Authorization Code
reference:  https://knowledge.informatica.com/s/article/572464?language=en_US
1) Prep! When you generate they Authorization Code, you will only have 5 minutes to use it to get the Refresh Token. It will help if you have this constructed beforehand so you can plug the code straight in.
2) In Postman, open a new scratch window and select POST (instead of GET from above)
3) Enter the URL: https://accounts.accesscontrol.windows.net/<bearer_realm>/tokens/OAuth/2 (notice you'll need to plug in your bearer realm)
4) Select the Headers tab and enter key "Content-Type" with the value of "application/x-www-form-urlencoded"
5) Next select the Body tab under the URL bar and select the Raw option.
6) Plug your values from your notes into this formula and plug that into the Body:
   - you will need to use the [URI converted](https://www.urlencoder.org/) Client Secret, but not the redirect uri.
```
grant_type=authorization_code
&client_id=<client_id>@<bearer_realm>
&client_secret=<client_secret>
&code=<auth_code>
&redirect_uri=<redirect_url>
&resource=<ClientID_from_Bearer_Realm_retrieval_Step_9*>/<site_host>@<bearer_realm>
```

This is how ours looks:
```
grant_type=authorization_code
&client_id=4b929dc2-6d2c-4937-a122-5448035f0b67@2ca68321-0eda-4908-88b2-424a8cb4b0f9
&client_secret=KZIC86XXXXXXXXXXXXXXXXXXXXXXXXY%3D  (X'd out most for security)
&code=<very long value we retrieve in the next step>
&redirect_uri=https://localhost/  (yes, this works with URL)
&resource=00000003-0000-0ff1-ce00-000000000000/uwprod.sharepoint.com@2ca68321-0eda-4908-88b2-424a8cb4b0f9
```

7) Construct a URL in the following way:
```
https://<your_site.sharepoint.com>/<subsitedomain>/_layouts/15/OAuthAuthorize.aspx?client_id=<ClientID_fromStepI>&scope=Web.Manage&response_type=code&redirect_uri=<redirect_uri_from_first_section>
```
   - you will need to use [this site](https://www.urlencoder.org/) (or any other URI converter) to change characters that aren't normally allowed in URLs
   - here is an example URL, notice the https://localhost/ has been converted at the end:
```
https://uwprod.sharepoint.com/sites/IICSRepo/_layouts/15/OAuthAuthorize.aspx?client_id=4b929dc2-6d2c-4937-a122-5448035f0b67&scope=Web.Manage&response_type=code&redirect_uri=https%3A%2F%2Flocalhost%2F
```
8) Make sure you're logged into your Sharepoint site as administrator, then either in that same browser tab or a new one, browse to the above URL.
   - when it loads, click the "Trust it" button.

    ![TrustIT](images/TrustIT.png)
   - After clicking "Trust It" you will get a "This site can't be reached" error, however the URL contains your 5 minute temporary Authorization Code.  

    ![DidntLoad](images/DidntLoadURL.png)
   - Plug this code into the body of your Postman formula above.
9) Press Send, save the Refresh Token.

    ![SuccessPM](images/PostmanSuccess.png)
## Create Informatica Sharepoint Online Connector

1) In the Administrator section of Informatica, select Connections.
2) Select New Connection in the upper right. 
3) Name your connection with an abbreviation of your team in the title for convenient use.
4) The client secret in this connection does NOT need to be converted to URI format.
5) The URL field CANNOT have an ending forward slash.
6) If your Sharepoint site is a subsite, it needs to have the subsite URL end as shown below.

![SuccessfulConnection](images/successfulconnection.png)
